==> haskell-split-0.2.3.1-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-split.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: split
version: 0.2.3.1
id: split-0.2.3.1-IJKK4pOCYGKud0jZImZke
key: split-0.2.3.1-IJKK4pOCYGKud0jZImZke
license: BSD3
copyright: (c) Brent Yorgey, Louis Wasserman 2008-2012
maintainer: byorgey@gmail.com
stability: stable
synopsis: Combinator library for splitting lists.
description:
    A collection of various methods for splitting
    lists into parts, akin to the \"split\" function
    found in several mainstream languages. Here is
    its tale:
    .
    Once upon a time the standard "Data.List" module
    held no function for splitting a list into parts
    according to a delimiter.  Many a brave
    lambda-knight strove to add such a function, but
    their striving was in vain, for Lo, the Supreme
    Council fell to bickering amongst themselves what
    was to be the essential nature of the One True
    Function which could cleave a list in twain (or
    thrain, or any required number of parts).
    .
    And thus came to pass the split package,
    comprising divers functions for splitting a list
    asunder, each according to its nature.  And the
    Supreme Council had no longer any grounds for
    argument, for the favored method of each was
    contained therein.
    .
    To get started, see the "Data.List.Split" module.
category: List
author: Brent Yorgey
exposed: True
exposed-modules:
    Data.List.Split Data.List.Split.Internals
abi: 11c7e52ba09ed521bfb02b0eb542ce91
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/split-0.2.3.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/split-0.2.3.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/split-0.2.3.1
hs-libraries: HSsplit-0.2.3.1-IJKK4pOCYGKud0jZImZke
depends:
    base-4.9.0.0
haddock-interfaces: /usr/share/doc/haskell-split/html/split.haddock
haddock-html: /usr/share/doc/haskell-split/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-split-0.2.3.2-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-split.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: split
version: 0.2.3.2
id: split-0.2.3.2-1dCEe3bkR6E9uyZt6jsXK
key: split-0.2.3.2-1dCEe3bkR6E9uyZt6jsXK
license: BSD3
copyright: (c) Brent Yorgey, Louis Wasserman 2008-2012
maintainer: byorgey@gmail.com
stability: stable
synopsis: Combinator library for splitting lists.
description:
    A collection of various methods for splitting
    lists into parts, akin to the \"split\" function
    found in several mainstream languages. Here is
    its tale:
    .
    Once upon a time the standard "Data.List" module
    held no function for splitting a list into parts
    according to a delimiter.  Many a brave
    lambda-knight strove to add such a function, but
    their striving was in vain, for Lo, the Supreme
    Council fell to bickering amongst themselves what
    was to be the essential nature of the One True
    Function which could cleave a list in twain (or
    thrain, or any required number of parts).
    .
    And thus came to pass the split package,
    comprising divers functions for splitting a list
    asunder, each according to its nature.  And the
    Supreme Council had no longer any grounds for
    argument, for the favored method of each was
    contained therein.
    .
    To get started, see the "Data.List.Split" module.
category: List
author: Brent Yorgey
exposed: True
exposed-modules:
    Data.List.Split Data.List.Split.Internals
abi: 0545c3c6e179e41e62082d50447e1d9a
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/split-0.2.3.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/split-0.2.3.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/split-0.2.3.2
hs-libraries: HSsplit-0.2.3.2-1dCEe3bkR6E9uyZt6jsXK
depends:
    base-4.9.0.0
haddock-interfaces: /usr/share/doc/haskell-split/html/split.haddock
haddock-html: /usr/share/doc/haskell-split/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
